SectionChangeNotifier class
- Inheritance
-
- Object
- ChangeNotifier
- SectionChangeNotifier
Constructors
- SectionChangeNotifier({SectionTableViewScrollToCallBack? sectionTableViewScrollTo})
Properties
- animate ↔ bool
-
getter/setter pair
- dirty ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionTableViewScrollTo ↔ SectionTableViewScrollToCallBack?
-
getter/setter pair
- topIndex ↔ IndexPath
-
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
int section, int row) → Future< bool> -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
jumpTo(
int section, int row) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited